==> TundereBird-0.23.tar.bz2: TundereBird-0.23/core/Smdn.Net.Imap4/Smdn.Net.Imap4/ImapMessage.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Text;

namespace Smdn.Net.Imap4 {
  public class ImapMessage : IImapMessageDynamicAttribute, IImapMessageStaticAttribute {
    public long Sequence {
      get { return sequence; }
    }

    public Uri Url {
      get
      {
        if (BaseUrl == null)
          throw new NotSupportedException();
        else
          return new Uri(BaseUrl, string.Format(";UID={0}", uid));
      }
    }

    protected virtual Uri BaseUrl {
      get; set;
    }

    public long Uid {
      get { return uid; }
      internal set { uid = value; }
    }

    public ImapEnvelope Envelope {
      get { return envelope; }
      internal set { envelope = value; }
    }

    public ImapBodyStructureBase BodyStructure {
      get { return bodyStructure; }
      internal set { bodyStructure = value; }
    }

    public string Rfc822Header {
      get { return rfc822Header; }
      internal set { rfc822Header = value; }
    }

    public long Rfc822Size {
      get { return rfc822Size; }
      internal set { rfc822Size = value; }
    }

    public string Rfc822Text {
      get { return rfc822Text; }
      internal set { rfc822Text = value; }
    }

    public byte[] Body {
      get { return body; }
      internal set { body = value; }
    }

    public ImapMessageFlagList Flags {
      get { return flags; }
      internal set { flags = value; }
    }

    public DateTimeOffset? InternalDate {
      get { return internalDate; }
      internal set { internalDate = value; }
    }

    /*
     * RFC 4551 - IMAP Extension for Conditional STORE Operation or Quick Flag Changes Resynchronization
     * http://tools.ietf.org/html/rfc4551
     */
    [CLSCompliant(false)]
    public ulong ModSeq {
      get { return modSeq; }
      internal set { modSeq = value; }
    }

    protected ImapMessage(long sequence)
    {
      if (sequence == 0)
        throw new ArgumentOutOfRangeException("sequence", "must be non-zero positive number");

      this.sequence = sequence;
    }

    public ImapMessage(byte[] body)
      : this(body, null, null)
    {
    }

    public ImapMessage(byte[] body, DateTimeOffset internalDate)
      : this(body, internalDate, null)
    {
    }

    public ImapMessage(byte[] body, ImapMessageFlagList flags)
      : this(body, null, flags)
    {
    }

    public ImapMessage(byte[] body, DateTimeOffset internalDate, ImapMessageFlagList flags)
      : this(body, (DateTimeOffset?)internalDate, flags)
    {
    }

    private ImapMessage(byte[] body, DateTimeOffset? internalDate, ImapMessageFlagList flags)
    {
      if (body == null)
        throw new ArgumentNullException("body");

      this.sequence = 0; // invalid sequence number
      this.body = body;
      this.internalDate = internalDate;
      this.flags = flags;
    }

    public override string ToString()
    {
      return string.Format("{{Uid={0}, Sequence={1}, Envelope={2}, BodyStructure={3}, Rfc822Header={4}, Rfc822Size={5}, Rfc822Text={6}, Body={7}, Flags={8}, InternalDate={9}, ModSeq={10}}}",
                           uid,
                           sequence,
                           envelope,
                           bodyStructure,
                           rfc822Header,
                           rfc822Size,
                           rfc822Text,
                           body,
                           flags,
                           internalDate,
                           modSeq);
    }

    private /*readonly*/ long sequence;
    private long uid = 0; // invalid uid number
    private ImapEnvelope envelope = null;
    private ImapBodyStructureBase bodyStructure = null;
    private string rfc822Header = null;
    private long rfc822Size = 0;
    private string rfc822Text = null;
    private byte[] body = null;
    private ImapMessageFlagList flags = new ImapMessageFlagList();
    private DateTimeOffset? internalDate = null;
    private ulong modSeq = 0; // invalid mod-sequence number;
  }
}

==> TundereBird-0.24.tar.bz2: TundereBird-0.24/core/Smdn.Net.Imap4/Smdn.Net.Imap4/ImapMessage.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Text;

namespace Smdn.Net.Imap4 {
  public class ImapMessage : IImapMessageDynamicAttribute, IImapMessageStaticAttribute {
    public long Sequence {
      get { return sequence; }
    }

    public virtual Uri Url {
      get { throw new NotSupportedException(); }
    }

    public long Uid {
      get { return uid; }
      internal set { uid = value; }
    }

    public ImapEnvelope Envelope {
      get { return envelope; }
      internal set { envelope = value; }
    }

    public ImapBodyStructureBase BodyStructure {
      get { return bodyStructure; }
      internal set { bodyStructure = value; }
    }

    public string Rfc822Header {
      get { return rfc822Header; }
      internal set { rfc822Header = value; }
    }

    public long Rfc822Size {
      get { return rfc822Size; }
      internal set { rfc822Size = value; }
    }

    public string Rfc822Text {
      get { return rfc822Text; }
      internal set { rfc822Text = value; }
    }

    public byte[] Body {
      get { return body; }
      internal set { body = value; }
    }

    public ImapMessageFlagList Flags {
      get { return flags; }
      internal set { flags = value; }
    }

    public DateTimeOffset? InternalDate {
      get { return internalDate; }
      internal set { internalDate = value; }
    }

    /*
     * RFC 4551 - IMAP Extension for Conditional STORE Operation or Quick Flag Changes Resynchronization
     * http://tools.ietf.org/html/rfc4551
     */
    [CLSCompliant(false)]
    public ulong ModSeq {
      get { return modSeq; }
      internal set { modSeq = value; }
    }

    protected ImapMessage(long sequence)
    {
      if (sequence == 0L)
        throw new ArgumentOutOfRangeException("sequence", "must be non-zero positive number");

      this.sequence = sequence;
    }

    public ImapMessage(byte[] body)
      : this(body, null, null)
    {
    }

    public ImapMessage(byte[] body, DateTimeOffset internalDate)
      : this(body, internalDate, null)
    {
    }

    public ImapMessage(byte[] body, ImapMessageFlagList flags)
      : this(body, null, flags)
    {
    }

    public ImapMessage(byte[] body, DateTimeOffset internalDate, ImapMessageFlagList flags)
      : this(body, (DateTimeOffset?)internalDate, flags)
    {
    }

    private ImapMessage(byte[] body, DateTimeOffset? internalDate, ImapMessageFlagList flags)
    {
      if (body == null)
        throw new ArgumentNullException("body");

      this.sequence = 0L; // invalid sequence number
      this.body = body;
      this.internalDate = internalDate;
      this.flags = flags;
    }

    public override string ToString()
    {
      return string.Format("{{Uid={0}, Sequence={1}, Envelope={2}, BodyStructure={3}, Rfc822Header={4}, Rfc822Size={5}, Rfc822Text={6}, Body={7}, Flags={8}, InternalDate={9}, ModSeq={10}}}",
                           uid,
                           sequence,
                           envelope,
                           bodyStructure,
                           rfc822Header,
                           rfc822Size,
                           rfc822Text,
                           body,
                           flags,
                           internalDate,
                           modSeq);
    }

    private /*readonly*/ long sequence;
    private long uid = 0L; // invalid uid number
    private ImapEnvelope envelope = null;
    private ImapBodyStructureBase bodyStructure = null;
    private string rfc822Header = null;
    private long rfc822Size = 0L;
    private string rfc822Text = null;
    private byte[] body = null;
    private ImapMessageFlagList flags = new ImapMessageFlagList();
    private DateTimeOffset? internalDate = null;
    private ulong modSeq = 0UL; // invalid mod-sequence number;
  }
}
